/**
 * Header file for vortex server and client 
 * TLS testing programs.
 */

#include <axl.h>
#include <vortex.h>
#include <vortex_tls.h>
#include <stdio.h>
#include <openssl/ssl.h>

#define TEST_PROFILE "http://iana.org/beep/TLS"

#ifdef NDEBUG
#define DEBUG(M)
#else
#define DEBUG(M) fprintf(stderr, M "\n")
#endif

typedef struct tls_config_type {
	const char *private_key;
	const char *public_cert;
	const char *peer_certs;
} tls_config;

/** 
 * Initializing the vortex library and TLS context.
 */
axl_bool test_vortex_context_init(VortexCtx *ctx,
				const char *private_key,
				const char *public_cert,
				const char *peer_certs);

/**
 * Defines and creates the SSL context.
 */
axlPointer test_ssl_ctx_creation(__attribute__((unused))VortexConnection *connection, axlPointer user_data);

/**
 * Initializes vortex library and TLS support (without context configuration).
 */
axl_bool test_simple_init(VortexCtx *ctx);

/**
 * Handler to check for a successful TLS connection.
 */
void tls_status_handler(VortexConnection *v_conn,
			VortexStatus v_status,
			const char *status_mesage,
			axlPointer user_data);
