/**
 * This file contains a small test client that illustrates
 * a bug with the Vortex Library's TLS negotiation.   
 */

#include "tls_bug.h"

#define EXPECTED_ARGC 4

void usage();

int main(int argc, char *argv[])
{
	if (argc != EXPECTED_ARGC) {
		usage();
		exit(-1);
	}

	VortexCtx *v_ctx = NULL;
	VortexConnection *v_conn = NULL;
	char *private_key = argv[1];
	char *public_cert = argv[2];
	char *peer_certs = argv[3];
	char *host = "127.0.0.1";
	char *port = "1234";

	// Initialize connection context for client.
	v_ctx = vortex_ctx_new();

	if (!test_vortex_context_init(v_ctx, private_key, public_cert, peer_certs)) {
		DEBUG("Context init failed.");
		goto out;
	}

	// Enable vortex auto TLS for every connection; no failures allowed.
	vortex_tls_set_auto_tls(v_ctx, axl_true, axl_false, NULL);

	// Attempt new connection with invalid/missing certs.
	v_conn = vortex_connection_new(v_ctx, host, port, NULL, NULL);

	// Call vortex_connection_ok with free on fail true.
	if (!vortex_connection_is_ok(v_conn, axl_true)) {
		DEBUG("Vortex connection setup failed:");
		goto out;
	}
out:
	DEBUG("Exiting...");
	vortex_exit_ctx(v_ctx, axl_false);
	return 0;
}

/**
 * Usage statement.
 */
void usage()
{
	fprintf(stderr, "Usage error: \n\
		You must specify the paths to the private key, public certificate, and peer certifacte directory.\n\
		Example: $> ./test_client ./keys/test-private-key.pem ./certs/test-certificate.pem ./certs\n");
	return;
}
