/**
 * This file contains a small test server that illustrates
 * a bug with the Vortex Library's TLS negotiation.   
 */

#include "tls_bug.h"

#define EXPECTED_ARGC 4

void usage();

int main(int argc, char *argv[])
{
	if (argc != EXPECTED_ARGC) {
		usage();
		exit(-1);
	}

	VortexCtx *v_ctx = NULL;
	char *private_key = argv[1];
	char *public_cert = argv[2];
	char *peer_certs = argv[3];
	char *host = "127.0.0.1";
	char *port = "1234";

	// Initialize connection context for server.
	v_ctx = vortex_ctx_new();

	if(!test_vortex_context_init(v_ctx, private_key, public_cert, peer_certs)){
		DEBUG("Context init failed.");
		goto out;
	}

	vortex_profiles_register(v_ctx, TEST_PROFILE,
				 NULL, NULL,
				 NULL, NULL,
				 NULL, NULL);

	// Set up server as a listener and wait for clients...
	vortex_listener_new(v_ctx, host, port, NULL, NULL);
	vortex_listener_wait(v_ctx);

out:
	DEBUG("Exiting...");
	vortex_exit_ctx(v_ctx, axl_false);
	return 0;
}

/**
 * Usage statement.
 */
void usage()
{
	fprintf(stderr, "Usage error:\n\
		You must specify the paths to the private key, public certificate, and peer certifacte directory.\n\
		Example: $> ./test_server ./keys/test-private-key.pem ./certs/test-certificate.pem ./certs\n");
	return;
}
